==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeDocumentType.h <==
// class gnu.xml.libxmlj.dom.GnomeDocumentType

// class file dependencies
// @dep_class cba4672b56d34e6 gnu_xml_libxmlj_dom_GnomeDocumentType
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeNode

#include "gnu/xml/libxmlj/dom/GnomeNode.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeDocumentType_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeDocumentType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_NamedNodeMap$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$refs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtable	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtype	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$getEntities$af5d82dd205f7c5d(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$getInternalSubset$b4f585a9a85dc9d7(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *);
extern struct _jc_object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$getNotations$77e099a33b295e2e(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$getPublicId$3ee590dd7a50665f(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method_info$getEntities$af5d82dd205f7c5d;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method_info$getInternalSubset$b4f585a9a85dc9d7;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method_info$getNotations$77e099a33b295e2e;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method_info$getPublicId$3ee590dd7a50665f;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method_info$getSystemId$dfda7e64149e1929;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vmethods {
	struct _jc_object	*(*getEntities$af5d82dd205f7c5d)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *);
	struct _jc_java_lang_String$object	*(*getInternalSubset$b4f585a9a85dc9d7)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *);
	struct _jc_object	*(*getNotations$77e099a33b295e2e)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *);
	struct _jc_java_lang_String$object	*(*getPublicId$3ee590dd7a50665f)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *);
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vmethods	gnu_xml_libxmlj_dom_GnomeDocumentType;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_refs	gnu_xml_libxmlj_dom_GnomeDocumentType;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeDocumentType;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object {
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtype _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeDocumentType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeDocumentType_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeDocumentType.h <==
// class gnu.xml.libxmlj.dom.GnomeDocumentType

// class file dependencies
// @dep_class cba4672b56d34e6 gnu_xml_libxmlj_dom_GnomeDocumentType
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeNode

#include "gnu/xml/libxmlj/dom/GnomeNode.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeDocumentType_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeDocumentType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_NamedNodeMap$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$refs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtable	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtype	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$getEntities$af5d82dd205f7c5d(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$getInternalSubset$b4f585a9a85dc9d7(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$getNotations$77e099a33b295e2e(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$getPublicId$3ee590dd7a50665f(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$getSystemId$dfda7e64149e1929(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method_info$getEntities$af5d82dd205f7c5d;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method_info$getInternalSubset$b4f585a9a85dc9d7;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method_info$getNotations$77e099a33b295e2e;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method_info$getPublicId$3ee590dd7a50665f;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method_info$getSystemId$dfda7e64149e1929;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vmethods {
	struct _jc_object	*(*getEntities$af5d82dd205f7c5d)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getInternalSubset$b4f585a9a85dc9d7)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getNotations$77e099a33b295e2e)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPublicId$3ee590dd7a50665f)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSystemId$dfda7e64149e1929)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vmethods	gnu_xml_libxmlj_dom_GnomeDocumentType;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_refs	gnu_xml_libxmlj_dom_GnomeDocumentType;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeDocumentType;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$object {
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentType$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$vtype _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeDocumentType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeDocumentType$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeDocumentType_H_ */
